import absolutePathRegexp from '../regexp/absolute-path';
import searchTypeRegexp from '../regexp/search-type';
import logger from '../../models/logger';
import commander from 'commander';
var CliErrors = (function () {
    function CliErrors() {
        this.errors = [
            { name: 'notFoundPath', message: 'Path not found. Use --path and input a valid url', checked: false },
            { name: 'invalidPath', message: 'Invalid path provided. Try again with another one', checked: false },
            { name: 'notFoundType', message: 'Type not found. Use --type and input a valid type', checked: false },
            { name: 'invalidType', message: 'Invalid type provided. Use --example for more details', checked: false },
        ];
    }
    CliErrors.prototype.check = function () {
        var notFoundPathIndex = this.errors.map(function (error) { return error.name; }).indexOf('notFoundPath');
        var invalidPathIndex = this.errors.map(function (error) { return error.name; }).indexOf('invalidPath');
        var notFoundTypeIndex = this.errors.map(function (error) { return error.name; }).indexOf('notFoundType');
        var invalidTypeIndex = this.errors.map(function (error) { return error.name; }).indexOf('invalidType');
        var path = commander.path;
        var type = commander.type;
        if (path || type) {
            if (!path) {
                this.errors[notFoundPathIndex].checked = true;
            }
            else if (!path.match(absolutePathRegexp)) {
                this.errors[invalidPathIndex].checked = true;
            }
            if (!type) {
                this.errors[notFoundTypeIndex].checked = true;
            }
            else if (!type.match(searchTypeRegexp)) {
                this.errors[invalidTypeIndex].checked = true;
            }
        }
    };
    CliErrors.prototype.show = function () {
        for (var _i = 0, _a = this.errors; _i < _a.length; _i++) {
            var error = _a[_i];
            if (error.checked) {
                logger.error(error.message);
            }
        }
    };
    Object.defineProperty(CliErrors.prototype, "hasError", {
        get: function () {
            for (var _i = 0, _a = this.errors; _i < _a.length; _i++) {
                var error = _a[_i];
                if (error.checked) {
                    return true;
                }
            }
            return false;
        },
        enumerable: false,
        configurable: true
    });
    return CliErrors;
}());
export { CliErrors };
export default CliErrors;
//# sourceMappingURL=cli-errors.js.map