"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LevelSorter = void 0;
var level_ignorer_1 = __importDefault(require("./level-ignorer"));
var LevelSorter = /** @class */ (function () {
    function LevelSorter(sort, ignore) {
        this.sort = sort;
        this.ignore = ignore;
    }
    LevelSorter.prototype.apply = function (levels) {
        var sort = this.sort;
        var ignore = this.ignore;
        var keys = sort.keys;
        var ignorer = new level_ignorer_1.default(ignore);
        var matches = this.getMatches(levels, keys);
        var fails = ignorer.apply(levels, matches);
        return matches.concat(fails);
    };
    LevelSorter.prototype.getMatches = function (levels, rules) {
        var allMatches = [];
        var notMatched = [];
        for (var _i = 0, rules_1 = rules; _i < rules_1.length; _i++) {
            var rule = rules_1[_i];
            var ruleMatches = [];
            for (var _a = 0, levels_1 = levels; _a < levels_1.length; _a++) {
                var level = levels_1[_a];
                var path = level.path;
                var includeRule = path.includes(rule);
                var equalsRule = path === rule;
                if (includeRule || equalsRule) {
                    ruleMatches.push(level);
                }
                else {
                    notMatched.push(level);
                }
            }
            allMatches = allMatches.concat(ruleMatches);
            levels = notMatched.map(function (level) { return level; });
            notMatched = [];
        }
        return allMatches;
    };
    return LevelSorter;
}());
exports.LevelSorter = LevelSorter;
exports.default = LevelSorter;
