"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = void 0;
var loader_1 = __importDefault(require("./loader"));
var chalk_1 = __importDefault(require("chalk"));
var Logger = /** @class */ (function () {
    function Logger() {
        this.loader = new loader_1.default();
        this.type = 'none';
        this.fixed = false;
    }
    Logger.prototype.cli = function (verbose) {
        this.type = verbose ? 'verbose' : 'cli';
    };
    Logger.prototype.success = function (message) {
        this.output(chalk_1.default.green(message), 'verbose');
    };
    Logger.prototype.warn = function (message) {
        this.output(chalk_1.default.yellow(message), 'verbose');
    };
    Logger.prototype.error = function (message) {
        this.output(chalk_1.default.red(message), 'verbose');
    };
    Logger.prototype.log = function (message, status) {
        this.output(this.format(message, status));
    };
    Logger.prototype.output = function (message, force) {
        var type = force ? force : this.type;
        var fixed = this.fixed;
        if (fixed) {
            process.stdout.clearLine(0);
            process.stdout.cursorTo(0);
        }
        if (type === 'verbose') {
            this.fixed = false;
            console.log(message);
        }
        else if (type === 'cli') {
            this.fixed = true;
            process.stdout.write(message);
        }
    };
    Logger.prototype.format = function (message, status) {
        var payload = message;
        var now = new Date();
        var date = now.toTimeString();
        var time = date.split(' ')[0];
        var dash = this.loader.next();
        var hour = chalk_1.default.blue(time);
        var loader = chalk_1.default.red(dash);
        var available = [
            { name: 'success', action: function (msg) { return chalk_1.default.green(msg); } },
            { name: 'warn', action: function (msg) { return chalk_1.default.yellow(msg); } },
            { name: 'error', action: function (msg) { return chalk_1.default.red(msg); } },
        ];
        if (status) {
            var name_1 = available.map(function (av) { return av.name; });
            var index = name_1.indexOf(status);
            if (index !== -1) {
                payload = available[index].action(message);
            }
        }
        return loader + " | [" + hour + "] " + payload;
    };
    return Logger;
}());
exports.logger = new Logger();
exports.default = exports.logger;
