"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CliErrors = void 0;
var absolute_path_1 = __importDefault(require("../regexp/absolute-path"));
var type_search_1 = __importDefault(require("../regexp/type-search"));
var logger_1 = __importDefault(require("../../models/logger"));
var commander_1 = __importDefault(require("commander"));
var CliErrors = /** @class */ (function () {
    function CliErrors() {
        this.errors = [
            { name: 'notFoundPath', message: 'Path not found. Use --path and input a valid url', checked: false },
            { name: 'invalidPath', message: 'Invalid path provided. Try again with another one', checked: false },
            { name: 'notFoundType', message: 'Type not found. Use --type and input a valid type', checked: false },
            { name: 'invalidType', message: 'Invalid type provided. Use --example for more details', checked: false },
        ];
    }
    CliErrors.prototype.check = function () {
        var notFoundPathIndex = this.errors.map(function (error) { return error.name; }).indexOf('notFoundPath');
        var invalidPathIndex = this.errors.map(function (error) { return error.name; }).indexOf('invalidPath');
        var notFoundTypeIndex = this.errors.map(function (error) { return error.name; }).indexOf('notFoundType');
        var invalidTypeIndex = this.errors.map(function (error) { return error.name; }).indexOf('invalidType');
        var path = commander_1.default.path;
        var type = commander_1.default.type;
        if (path || type) {
            if (!path) {
                this.errors[notFoundPathIndex].checked = true;
            }
            else if (!path.match(absolute_path_1.default)) {
                this.errors[invalidPathIndex].checked = true;
            }
            if (!type) {
                this.errors[notFoundTypeIndex].checked = true;
            }
            else if (!type.match(type_search_1.default)) {
                this.errors[invalidTypeIndex].checked = true;
            }
        }
    };
    CliErrors.prototype.show = function () {
        for (var _i = 0, _a = this.errors; _i < _a.length; _i++) {
            var error = _a[_i];
            if (error.checked) {
                logger_1.default.error(error.message);
            }
        }
    };
    Object.defineProperty(CliErrors.prototype, "hasError", {
        get: function () {
            for (var _i = 0, _a = this.errors; _i < _a.length; _i++) {
                var error = _a[_i];
                if (error.checked) {
                    return true;
                }
            }
            return false;
        },
        enumerable: false,
        configurable: true
    });
    return CliErrors;
}());
exports.CliErrors = CliErrors;
exports.default = CliErrors;
